@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocoirc::Status::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocoirc::Status::VERSION = '0.32';
+  $App::Pocoirc::Status::VERSION = '0.33';
 }
 
 use strict;
@@ -48,6 +48,7 @@ sub PCI_register {
             socks_failed
             socks_rejected
             raw
+            raw_out
         ));
     }
     return 1;
@@ -101,7 +102,7 @@ sub _event_debug {
        push @output, "ARG$i: " . _dump(${ $args->[$i] });
     }
 
-    $self->{status}{$irc}->('debug', "Event $event: ".join(', ', @output));
+    $self->{status}{$irc}->('debug', "$event: ".join(', ', @output));
     return;
 }
 
@@ -240,7 +241,7 @@ sub S_quit {
 sub S_shutdown {
     my ($self, $irc) = splice @_, 0, 2;
     $self->_event_debug($irc, 'S_shutdown', \@_) if $self->{Trace};
-    $self->{status}{$irc}->('normal', 'Shutting down');
+    $self->{status}{$irc}->('normal', 'IRC component shut down');
     return PCI_EAT_NONE;
 }
 
@@ -272,10 +273,19 @@ sub S_raw {
     my ($self, $irc) = splice @_, 0, 2;
     my $raw = _normalize(${ $_[0] });
     return PCI_EAT_NONE if !$self->{Verbose};
-    $self->{status}{$irc}->('debug', "Raw: $raw");
+    $self->{status}{$irc}->('debug', "<<< $raw");
     return PCI_EAT_NONE;
 }
 
+sub S_raw_out {
+    my ($self, $irc) = splice @_, 0, 2;
+    my $raw = ${ $_[0] };
+    $raw = strip_color($raw);
+    $raw = strip_formatting($raw);
+    return PCI_EAT_NONE if !$self->{Verbose};
+    $self->{status}{$irc}->('debug', ">>> $raw");
+    return PCI_EAT_NONE;
+}
 sub _default {
     my ($self, $irc, $event) = splice @_, 0, 3;
     return PCI_EAT_NONE if !$self->{Trace};
